==> plugin.video.orange.fr-2.1.3.zip: plugin.video.orange.fr/doc/README.fr.md <==
# Orange TV France pour Kodi
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/releases)
[![Kodi version](https://img.shields.io/badge/kodi%20version-v21-blue)](https://kodi.tv/)
[![GitHub](https://img.shields.io/github/license/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/blob/master/LICENSE)

_Cet addon n'est pas officiellement supporté par Orange. Tous les produits, logos et marques déposées mentionnés dans ce projet sont la propriété de leurs propriétaires respectifs._

## Description
Cet addon ajoute la TV d'Orange à Kodi. Toutes les chaînes inclues dans votre abonnement sont maintenant directement accessibles depuis Kodi !

Cet addon inclue :
- la télé en direct dans Kodi TV (en utilisant [IPTV Simple PVR](https://github.com/kodi-pvr/pvr.iptvsimple))
- les programmes en replay
- l'accès aux chaînes payantes qui font partie de votre souscription (pour le direct et le replay)

## Installation
Orange TV France est disponible directement depuis le dépôt principal de Kodi. L'intégration à la télévision sur Kodi se fait via [IPTV Manager](https://github.com/add-ons/service.iptv.manager). Vous pouvez l'installer et l'activer directement depuis les réglages de l'addon. Une fois configuré, les chaînes et le programme TV se chargent automatiquement.

Vous devriez maintenant voir toutes les chaînes regroupées par categories dans la section TV. S'il n'est pas déjà installé, Kodi vous demandera d'installer l'outil de décryptage quand vous regarderez une chaîne pour la première fois.

N'oubliez pas de configurer IPTV Manager correctement et de sélectionner le bon fournisseur dans les paramètres !

Si vous avez besoin de la dernière version, vous pouvez toujours télécharger la dernière archive ZIP depuis [cette page](https://github.com/BreizhReloaded/plugin.video.orange.fr/releases/latest) et installez-la directement depuis Kodi (Settings > Addons > Install from ZIP). Installez ensuite les dépendences depuis l'écan de l'adddon (My addons > Video addons > Orange TV France > Dependencies).

## Fournisseurs disponibles
| Pays      | Fournisseur       |  |
|:---------:|:------------------|:-|
| 🇫🇷        | Orange            |  |
| 🇫🇷        | Orange Caraïbe    |  |
| 🇫🇷        | Orange Réunion    | merci à [@starmate](https://github.com/starmate) et [@sae-gfc](https://github.com/sae-gfc)

## Limitations connues
- Qualité vidéo limitée à 720p, Orange ne propose pas plus sur leur plateforme web
- Ne fonctionne que depuis les zones listées et testées (pour le moment France métropolitaine, Caraïbes Françaises et La Réunion)

==> plugin.video.orange.fr-2.1.4.zip: plugin.video.orange.fr/doc/README.fr.md <==
# Orange TV France pour Kodi
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/releases)
[![Kodi version](https://img.shields.io/badge/kodi%20version-v21-blue)](https://kodi.tv/)
[![GitHub](https://img.shields.io/github/license/f-lawe/plugin.video.orange.fr)](https://github.com/f-lawe/plugin.video.orange.fr/blob/master/LICENSE)

_Cet addon n'est pas officiellement supporté par Orange. Tous les produits, logos et marques déposées mentionnés dans ce projet sont la propriété de leurs propriétaires respectifs._

## Description
Cet addon ajoute la TV d'Orange à Kodi. Toutes les chaînes inclues dans votre abonnement sont maintenant directement accessibles depuis Kodi !

Cet addon inclue :
- la télé en direct dans Kodi TV (en utilisant [IPTV Simple PVR](https://github.com/kodi-pvr/pvr.iptvsimple))
- les programmes en replay
- l'accès aux chaînes payantes qui font partie de votre souscription (pour le direct et le replay)

## Installation
Orange TV France est disponible directement depuis le dépôt principal de Kodi. L'intégration à la télévision sur Kodi se fait via [IPTV Manager](https://github.com/add-ons/service.iptv.manager). Vous pouvez l'installer et l'activer directement depuis les réglages de l'addon. Une fois configuré, les chaînes et le programme TV se chargent automatiquement.

Vous devriez maintenant voir toutes les chaînes regroupées par categories dans la section TV. S'il n'est pas déjà installé, Kodi vous demandera d'installer l'outil de décryptage quand vous regarderez une chaîne pour la première fois.

N'oubliez pas de configurer IPTV Manager correctement et de sélectionner le bon fournisseur dans les paramètres !

Si vous avez besoin de la dernière version, vous pouvez toujours télécharger la dernière archive ZIP depuis [cette page](https://github.com/BreizhReloaded/plugin.video.orange.fr/releases/latest) et installez-la directement depuis Kodi (Settings > Addons > Install from ZIP). Installez ensuite les dépendences depuis l'écan de l'adddon (My addons > Video addons > Orange TV France > Dependencies).

## Fournisseurs disponibles
| Pays      | Fournisseur       |  |
|:---------:|:------------------|:-|
| 🇫🇷        | Orange            |  |
| 🇫🇷        | Orange Caraïbe    |  |
| 🇫🇷        | Orange Réunion    | merci à [@starmate](https://github.com/starmate) et [@sae-gfc](https://github.com/sae-gfc)

## Limitations connues
- Qualité vidéo limitée à 720p, Orange ne propose pas plus sur leur plateforme web
- Ne fonctionne que depuis les zones listées et testées (pour le moment France métropolitaine, Caraïbes Françaises et La Réunion)

## Sponsoring
Vous aimez ce projet ? Aidez-moi à travailler dessus !

[![Donate with PayPal](https://www.paypalobjects.com/fr_FR/i/btn/btn_donate_LG.gif)](https://www.paypal.com/donate/?hosted_button_id=PNVV6FEQU94JG)
